# Function components in `ngMock`

Name | Description
--- | ---
angular.mock.dump | NOTE: This is not an injectable instance, just a globally available function.
angular.mock.module | NOTE: This function is also published on window for easy access. NOTE: This function is declared ONLY WHEN running tests with jasmine or mocha
angular.mock.module.sharedInjector | NOTE: This function is declared ONLY WHEN running tests with jasmine or mocha
angular.mock.inject | NOTE: This function is also published on window for easy access. NOTE: This function is declared ONLY WHEN running tests with jasmine or mocha